@@ -6,7 +6,7 @@ require 'slop/types'
 require 'slop/error'
 
 module Slop
-  VERSION = '4.2.0'
+  VERSION = '4.5.0'
 
   # Parse an array of options (defaults to ARGV). Accepts an
   # optional hash of configuration options and block.
@@ -31,6 +31,10 @@ module Slop
   # Returns true if an option is defined.
   def self.option_defined?(name)
     const_defined?(string_to_option(name.to_s))
+  rescue NameError
+    # If a NameError is raised, it wasn't a valid constant name,
+    # and thus couldn't have been defined.
+    false
   end
 
   # Example:
